API Reference
=============

Checks
------

.. autosummary::
    :toctree: generated
    :nosignatures:

    geomancy.checks.Check
    geomancy.checks.Result
    geomancy.checks.CheckException
    geomancy.checks.CheckEnv
    geomancy.checks.CheckExec
    geomancy.checks.CheckPath
    geomancy.checks.CheckPlatform
    geomancy.checks.CheckPythonPackage
    geomancy.checks.aws.CheckAwsS3
    geomancy.checks.aws.CheckAwsIam

Config
------

.. autosummary::
    :toctree: generated
    :nosignatures:

    geomancy.config.Config
    geomancy.config.Parameter
    geomancy.config.ConfigException

Environment
-----------

.. autosummary::
    :toctree: generated
    :nosignatures:

    geomancy.environment.sub_env
    geomancy.environment.parse_env
    geomancy.environment.load_env
